From bippy-c9c4e1df01b2 Mon Sep 17 00:00:00 2001
From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
To: <linux-cve-announce@vger.kernel.org>
Reply-to: <cve@kernel.org>, <linux-kernel@vger.kernel.org>
Subject: CVE-2024-42283: net: nexthop: Initialize all fields in dumped nexthops

Description
===========

In the Linux kernel, the following vulnerability has been resolved:

net: nexthop: Initialize all fields in dumped nexthops

struct nexthop_grp contains two reserved fields that are not initialized by
nla_put_nh_group(), and carry garbage. This can be observed e.g. with
strace (edited for clarity):

    # ip nexthop add id 1 dev lo
    # ip nexthop add id 101 group 1
    # strace -e recvmsg ip nexthop get id 101
    ...
    recvmsg(... [{nla_len=12, nla_type=NHA_GROUP},
                 [{id=1, weight=0, resvd1=0x69, resvd2=0x67}]] ...) = 52

The fields are reserved and therefore not currently used. But as they are, they
leak kernel memory, and the fact they are not just zero complicates repurposing
of the fields for new ends. Initialize the full structure.

The Linux kernel CVE team has assigned CVE-2024-42283 to this issue.


Affected and fixed versions
===========================

	Issue introduced in 5.3 with commit 430a049190de and fixed in 5.4.282 with commit fd06cb4a5fc7
	Issue introduced in 5.3 with commit 430a049190de and fixed in 5.10.224 with commit 5cc4d71dda2d
	Issue introduced in 5.3 with commit 430a049190de and fixed in 5.15.165 with commit 9e8f558a3afe
	Issue introduced in 5.3 with commit 430a049190de and fixed in 6.1.103 with commit 1377de719652
	Issue introduced in 5.3 with commit 430a049190de and fixed in 6.6.44 with commit 7704460acd7f
	Issue introduced in 5.3 with commit 430a049190de and fixed in 6.10.3 with commit a13d3864b76a
	Issue introduced in 5.3 with commit 430a049190de and fixed in 6.11 with commit 6d745cd0e972

Please see https://www.kernel.org for a full list of currently supported
kernel versions by the kernel community.

Unaffected versions might change over time as fixes are backported to
older supported kernel versions.  The official CVE entry at
	https://cve.org/CVERecord/?id=CVE-2024-42283
will be updated if fixes are backported, please check that for the most
up to date information about this issue.


Affected files
==============

The file(s) affected by this issue are:
	net/ipv4/nexthop.c


Mitigation
==========

The Linux kernel CVE team recommends that you update to the latest
stable kernel version for this, and many other bugfixes.  Individual
changes are never tested alone, but rather are part of a larger kernel
release.  Cherry-picking individual commits is not recommended or
supported by the Linux kernel community at all.  If however, updating to
the latest release is impossible, the individual changes to resolve this
issue can be found at these commits:
	https://git.kernel.org/stable/c/fd06cb4a5fc7bda3dea31712618a62af72a1c6cb
	https://git.kernel.org/stable/c/5cc4d71dda2dd4f1520f40e634a527022e48ccd8
	https://git.kernel.org/stable/c/9e8f558a3afe99ce51a642ce0d3637ddc2b5d5d0
	https://git.kernel.org/stable/c/1377de719652d868f5317ba8398b7e74c5f0430b
	https://git.kernel.org/stable/c/7704460acd7f5d35eb07c52500987dc9b95313fb
	https://git.kernel.org/stable/c/a13d3864b76ac87085ec530b2ff8e37482a63a96
	https://git.kernel.org/stable/c/6d745cd0e9720282cd291d36b9db528aea18add2
